# ../addons/eventscripts/gungame/scripts/custom/gg_cheap_equip/gg_cheap_equip.py

# ============================================================================
# >> IMPORTS
# ============================================================================
# Eventscripts Imports
import es
from cmdlib import registerSayCommand
from cmdlib import unregisterSayCommand
import gamethread
from playerlib import getPlayer

# GunGame Imports
from gungame51.core.addons.shortcuts import AddonInfo
from gungame51.core.addons import PriorityAddon
from gungame51.core.players.shortcuts import Player
from gungame51.core.players.shortcuts import setAttribute
from gungame51.core.players.shortcuts import deleteAttribute
from gungame51.core.messaging.shortcuts import msg

# ============================================================================
# >> ADDON REGISTRATION/INFORMATION
# ============================================================================
info = AddonInfo()
info.name = "gg_cheap_equip"
info.title = "GG Cheap Equip"
info.author = "Warren Alpert"
info.version = "0.1"
info.translations = ["gg_cheap_equip"]

# ============================================================================
# >> GLOBAL VARIABLES
# ============================================================================
gg_cheap_equip_command = str(es.ServerVar("gg_cheap_equip_command"))
gg_cheap_equip_uses = int(es.ServerVar("gg_cheap_equip_uses"))
# Make a list of weapons
gg_cheap_equip_exceptions = str(es.ServerVar("gg_cheap_equip_exceptions")) \
                                                                    .split(",")

# Be enabled by default
enabled = True

# ============================================================================
# >> LOAD & UNLOAD
# ============================================================================
def load():
    es.dbgmsg(0, "Loaded: %s" % info.name)

    if gg_cheap_equip_uses:
        # Set everyone's equipUses to 0
        setAttribute("#all", "equipUses", 0)

    # Register the say command
    registerSayCommand(gg_cheap_equip_command, cheap_equip_command, 
                                    "Allows players to re-equip themselves.")

def unload():
    es.dbgmsg(0, "Unloaded: %s" % info.name)

    if gg_cheap_equip_uses:
        # Delete the custom player attribute
        deleteAttribute("#all", "equipUses")

    # Unregister the say command
    unregisterSayCommand(gg_cheap_equip_command)
    
# ============================================================================
# >> GAME EVENTS
# ============================================================================
def cheap_equip_command(userid, args):
    # If gg_cheap_equip is not enabled or a PriorityAddon (primarily warmup) is
    # loaded, stop here
    if not enabled or PriorityAddon():
        msg(userid, "CheapEquip_NotStarted", {"command":gg_cheap_equip_command}
                                                                ,prefix=True)
        return

    # Is player dead or a spectator?
    if getPlayer(userid).isdead or es.getplayerteam(userid) < 2:
        msg(userid, "CheapEquip_NotPlaying", {"command":gg_cheap_equip_command}
                                                                ,prefix=True)
        return

    ggPlayer = Player(userid)
    
    # If the player's current weapon is in the exceptions list, stop here
    if ggPlayer.weapon in gg_cheap_equip_exceptions:
        msg(userid, "CheapEquip_NotAllowed", {"command":gg_cheap_equip_command,
                                            "weapon":ggPlayer.weapon}, True)
        return

    if gg_cheap_equip_uses:
        # If the player has used all of their uses for this life,
        # tell them and stop here
        if ggPlayer.equipUses >= gg_cheap_equip_uses:
            msg(userid, "CheapEquip_AlreadyUsed", {"command":
                    gg_cheap_equip_command, "max_uses":gg_cheap_equip_uses}, True)
            return
        else:
            # Otherwise, increment their uses
            ggPlayer.equipUses += 1

    # Strip and re-equip the player
    ggPlayer.strip(True)
    gamethread.delayed(0.05, ggPlayer.give_weapon)

def player_disconnect(event_var):
    if gg_cheap_equip_uses:
        # Players may disconnect before activating, causing an error
        try:
            # Delete the custom player attribute
            deleteAttribute(int(event_var["userid"]), "equipUses")
        except:
            return

def player_spawn(event_var):
    if gg_cheap_equip_uses:
        # Set their uses to 0
        setAttribute(int(event_var["userid"]), "equipUses", 0)

def es_map_start(event_var):
    global enabled

    # Disable this addon until the next gg_start (For the first time the server
    # starts)
    enabled = False

def gg_win(event_var):
    global enabled

    # Disable this addon until the next gg_start
    enabled = False

def gg_start(event_var):
    global enabled

    # Enable gg_cheap_equip
    enabled = True